@@ -13,8 +13,10 @@ vred = function(a1, a2=NULL, vredTyp = "hyp", variogramModel,
       a2 = a1[[2]]
       a1 = a1[[1]]
     } else if (is.null(a2)) a2 = a1
-    a1 = coordinates(a1)
-    a2 = coordinates(a2)
+    if (inherits(a1, "Spatial")) a1 = coordinates(a1)
+    if (inherits(a2, "Spatial")) a2 = coordinates(a2)
+    if (inherits(a1, "sf") | inherits(a1, "sfc")) a1 = st_coordinates(a1)
+    if (inherits(a2, "sf") | inherits(a2, "sfc")) a2 = st_coordinates(a2)
     ip1 = dim(a1)[1]
     ip2 = dim(a2)[1]
     vreda = .Fortran("vredind", ci, ip1, ip2, a1, a2, length(param), param, imod)
